use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
BooK
Bruhat
Christian
ConfigSlicer
DAGOLDEN
DAGOLDEN's
David
Dist
Eric
Etheridge
GatherDir
Golden
Johnson
Karen
Keedi
Kim
Philippe
PluginBundle
PluginRemover
Pod
PodCoverage
Romanov
Sergey
Walde
Weaver
Zilla
attr
book
complefor
cpanfile
dagolden
eric
ether
ini
keedi
lib
walde
김도형
